@@ -18,6 +18,6 @@
 
 #define NL_MAJOR 1
 #define NL_MINOR 2
-#define NL_REV   2
-#define NL_DATE  "Jul 24, 2002"
-#define VERSION  "1.2.2"
+#define NL_REV   3
+#define NL_DATE  "Aug 14, 2002"
+#define VERSION  "1.2.3"
